@@ -13,10 +13,6 @@ class LLMAgentMemory(Memory):
     messages: Messages = Field(default_factory=Messages)
     instructions: LLMPrompt | None = Field(default=None)
 
-    def __init__(self, instructions: LLMPrompt | None = None) -> None:
-        super().__init__()
-        self.reset(instructions)
-
     def reset(
         self, instructions: LLMPrompt | None = None, ctx: RunContext[Any] | None = None
     ):
