@@ -1,12 +1,10 @@
 from abc import ABC, abstractmethod
-from typing import Any, TypeVar
+from typing import Any
 
-from pydantic import BaseModel, ConfigDict
+from pydantic import BaseModel
 
 from .run_context import RunContext
 
-MemT = TypeVar("MemT", bound="Memory")
-
 
 class Memory(BaseModel, ABC):
     @abstractmethod
@@ -33,8 +31,6 @@ class Memory(BaseModel, ABC):
     def __repr__(self) -> str:
         return f"{self.__class__.__name__}()"
 
-    model_config = ConfigDict(arbitrary_types_allowed=True)
-
 
 class DummyMemory(Memory):
     def reset(
